@@ -1,4 +1,4 @@
-// $Id: main_thread.c,v 1.18 2006/05/10 11:28:23 khlut Exp $
+// $Id: main_thread.c,v 1.19 2006/05/13 20:57:46 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -36,6 +36,7 @@ NPNetscapeFuncs NPN;
 NPIdentifier ready,	run,	src;
 int debug=1;
 int mozillastreams=1;
+int background=-1;
 static int instance_cnt;
 
 /*
@@ -482,6 +483,20 @@ NPError NPP_SetWindow(NPP instance, NPWindow* npwindow)
            (int)npwindow->ws_info, (int)npwindow->type );
     
     if(Pd->xid!=xid) {
+	if(background>=0) {
+	    Display *display = ((NPSetWindowCallbackStruct *)npwindow->ws_info)->display;
+	    XWindowAttributes atr;
+	    if(XGetWindowAttributes(display, xid, &atr)) {
+		XGCValues gcv;
+		gcv.foreground= background? XWhitePixelOfScreen(atr.screen)
+				          : XBlackPixelOfScreen(atr.screen);
+		GC gc = XCreateGC(display, xid, GCForeground, &gcv);
+		XFillRectangle(display, xid, gc, 0, 0, atr.width, atr.height);
+		XSetWindowBackground(display, xid, gcv.foreground);
+		XFreeGC(display, gc);
+		Debug("wsize: %dx%d bg=%d\n", atr.width, atr.height, gcv.foreground);
+	    }
+	}
     //TODO: display
 	send_value_hex(Pd,"xid", (int)xid);
 	if(!Pd->xid) send_value_hex(Pd,"run", 1);
