@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.29 2006/05/13 20:57:46 khlut Exp $
+# $Id: mplayer.pl,v 1.30 2006/08/10 09:02:50 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -52,6 +52,8 @@ load_config();
 
 $v{quittimeout}=2; #wait 2 seconds after send quit command or interruptable signal
 $v{play}=1;
+$v{flip}=0;
+$v{mirror}=0;
 $loop=1;
 $href="/dev/fd/3";
 # output window
@@ -194,7 +196,7 @@ sub ifilt{
     cmd("filepos=$v{filepos}")      if $v{filepos};
     cmd("framestep=$v{framestep}")  if $v{framestep};
     while(<STDIN>){
-	cmd $_;
+	cmd($_);
     }
 }
 
@@ -289,6 +291,9 @@ print "debug=1\n", # list of control variables
       "save=\n",
       "fps=\n",
       "lowres=\n",
+      "rotate=0\n",
+      "flip=0\n",
+      "mirror=0\n",
       "src=\n",
       "href=\n" unless($ARGV[0] eq '--no-vars');
       
@@ -355,6 +360,20 @@ while (<STDIN>){
 			(defined $ENV{GENRES_BACKGROUND} && $ENV{GENRES_BACKGROUND} eq "0")? (65535,65535,65535):(0,0,0)
 		) );
 	    }
+	    $p=0;
+	    if( $v{rotate} eq 90 ) { $p=5 }
+	    elsif( $v{rotate} eq 180 ) { $p=3 }
+	    elsif( $v{rotate} eq 270 ) { $p=6 }
+	    $p ^= 2 if( $v{flip} !~ m/false|no|0/i );
+	    $p ^= 1 if( $v{mirror} !~ m/false|no|0/i );
+	    if($p&4) {
+		$FILTERS.=",rotate=".($p&3);
+	    }else{
+		$FILTERS.=",mirror" if( $p&1 );
+		$FILTERS.=",flip" if( $p&2 );
+	    }
+	    print "filters=$FILTERS\n";
+	    $OPTS.=" -vf ".substr($FILTERS,1) if( $FILTERS );
 	    $OPTS.=" -xy '$v{width}'"	if( $v{width} && $v{width}!~"%" );
 	    $OPTS.=" -lavdopts lowres='$v{lowres}'" if( $v{lowres} );
 	    $OPTS.=" -fps '$v{fps}'"		if( $v{fps} );
